@@ -70,29 +70,34 @@ class Settings(object):
             return getattr(django_settings, name)
 
         # First access for an editable setting - load from DB into cache.
+        # Also remove settings from the DB that are no longer registered.
         if setting["editable"] and not self._loaded:
             from mezzanine.conf.models import Setting
             settings = Setting.objects.filter(site=Site.objects.get_current())
+            removed = []
             for setting_obj in settings:
-                setting_type = registry[setting_obj.name]["type"]
-                if setting_type is bool:
-                    setting_value = setting_obj.value != "False"
+                try:
+                    setting_type = registry[setting_obj.name]["type"]
+                except KeyError:
+                    removed.append(setting_obj.id)
                 else:
-                    setting_value = setting_type(setting_obj.value)
-                self._editable_cache[setting_obj.name] = setting_value
+                    if setting_type is bool:
+                        setting_value = setting_obj.value != "False"
+                    else:
+                        setting_value = setting_type(setting_obj.value)
+                    self._editable_cache[setting_obj.name] = setting_value
+            if removed:
+                Setting.objects.filter(id__in=removed).delete()
             self._loaded = True
 
         # Use cached editable setting if found, otherwise use default.
         try:
-            setting_value = self._editable_cache[name]
+            return self._editable_cache[name]
         except KeyError:
-            pass
-        else:
-            return setting_value
-        return setting["default"]
+            return setting["default"]
 
 
-other_apps = [a for a in django_settings.INSTALLED_APPS if a != __name__]
+other_apps = [app for app in django_settings.INSTALLED_APPS if app != __name__]
 for app in [__name__] + other_apps:
     try:
         __import__("%s.defaults" % app)
